/*******************************************************************************
 *  PorjectName		: iRTK5WEB
 *  FileName	  	: ant_ctrl.js
*  Author	  		: guol add by 2021-08-09
 *******************************************************************************/

var ant_param = {
    ant_name: 'AT35101H',
    ngs_name: 'HITAT35101H',
    base_high: 0,
    radius: 0.09400,
    l1_n: 0.00130,
    l1_e: -0.00100,
    l1_u: 0.05090,
    l2_n: 0.00040,
    l2_e: -0.00180,
    l2_u: 0.05620,
}

/* 存放从文件中读取的天线参数的值 */
var ant_val_list = new Array();

/*******************************************************************************
 * 名称：ReadAntFileToRefreshPage
 * 功能：获取天线文件并解析参数显示到界面
 * 形参：param	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/
function ReadAntFileToRefreshPage(param)
{
    var ant_txt = $.ajax({
        url: '../ant_file/extern_ant.arl',
        type: 'GET',
        async: false,
        timeout: 2000,
        err: function (){
            console.log("GetAntParam err!!");
            showLoader("读取天线参数失败！", 2000);
        },
        success: function (data){
            // console.log("data: " + data);
            var txt_split_arr = data.split("\n");
            // console.log("line is: " + txt_split_arr.length);
            $.each(txt_split_arr, function(i, val){
                // console.log("split txt is: " + val);
                var line = val.split(",");
                var j = 0;
                var ant_list = new Object();
                //此处对应中海达天线文件格式：HI-TARGET_V2.5.arl
                ant_list.ant_name = line[j++];
                ant_list.instruction = line[j++];
                ant_list.radius = line[j++];
                ant_list.base_high = line[j++];
                ant_list.l1_u = line[j++];
                ant_list.l2_u = line[j++];
                ant_list.ngs_name = line[j++];
                ant_list.l1_n = line[j++];
                ant_list.l1_e = line[j++];
                ant_list.l2_n = line[j++];
                ant_list.l2_e = line[j++];

                /* 若文件中的天线名称和当前使用的天线(数据库)重名，则将文件中的过滤掉，以数据库的为准 */
                if ( (ant_list.ant_name != param.ant_name) && (ant_list.ant_name.length > 0) ){
                    ant_val_list.push(ant_list);
                    $('#ant_type_id').append("<option value='" + ant_list.ant_name + "' >"
                        + ant_list.ant_name + "</option>");
                }
            });
        }
    });

}

/*******************************************************************************
 * 名称：RefushAntParam
 * 功能：根据界面选中的天线刷新对应的天线参数
 * 形参：ant_name	->	天线名称
 * 返回：空
 * 说明：无
 ******************************************************************************/
function RefushAntParam(ant_name)
{
    /* 若当前使用的天线名称和天线文件中的冲突，则以当前使用的参数为准（数据库中保存的） */
    if ( ant_name === ant_param.ant_name ){
        $('#radius_id').val(ant_param.radius);
        $('#l1_high_id').val(ant_param.l1_u);
        $('#l2_high_id').val(ant_param.l2_u);
        $('#measure_high_id').val(ant_param.base_high);
    } else {
        $.each(ant_val_list, function (index, val){
            // console.log("choose name is: " + ant_name + ", index is: " + index + ", current name is: " + val.ant_name);
            if( val.ant_name === ant_name ){
                // console.log("ngs_name is: " + ant_val_list[index].ngs_name);
                $('#radius_id').val(ant_val_list[index].radius);
                $('#l1_high_id').val(ant_val_list[index].l1_u);
                $('#l2_high_id').val(ant_val_list[index].l2_u);
                $('#measure_high_id').val(ant_val_list[index].base_high);
            }
        });
    }
}

/*******************************************************************************
 * 名称：GetCurrentAnt
 * 功能：获取当前使用的天线参数
 * 形参：ctrl_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/
function GetCurrentAnt(param)
{
    //将当前使用的参数设置为选中状态
    $('#ant_type_id').append("<option value='" + param.ant_name + "' checked>"
        + param.ant_name + "</option>");
    $('#ant_type_id').val(param.ant_name);
    $('#radius_id').val(param.radius);
    $('#l1_high_id').val(param.l1_u);
    $('#l2_high_id').val(param.l2_u);
    $('#measure_high_id').val(param.base_high);
}

/*******************************************************************************
 * 名称：RefreshAntInfoPage
 * 功能：更新天线参数状态页面
 * 形参：ctrl_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/

function RefreshAntInfoPage(param)
{
    /* 获取天线文件并解析参数显示到界面 */
    ReadAntFileToRefreshPage(param);
    /* 获取当前使用的天线参数 */
    GetCurrentAnt(param);
}

/*******************************************************************************
 * 名称：GetAntlInfo
 * 功能：获取天线参数信息
 * 形参：无
 * 返回：空
 * 说明：无
 ******************************************************************************/

function GetAntInfo()
{
    iRTK5HTTPRequest('system&get_ant', '', function(dat)
    {
        console.log(dat); /* 向控制台输出接收到的CGI数据 */
        ant_param = JSON.parse(dat); /* 解析JSON数据 */
        RefreshAntInfoPage(ant_param);
        console.log("CGI OK!");
    });

}

function SetInputValAndSetReadonlyState(id, val, state)
{
    $(id).val(val);
    if ( state == 'on' ){
        $(id).attr('readonly', 'readonly');
    } else {
        $(id).removeAttr('readonly');
    }
}
/*******************************************************************************
 * 名称：ChangeAntParam
 * 功能：选择自定义天线，天线参数可编辑
 * 形参：value	->	是否开启自定义天线参数
 * 返回：空
 * 说明：打开自定义后，界面输入框改为可编辑状态
 ******************************************************************************/
function ChangeElementStat(value)
{
    /* 打开自定义后，清空参数，界面输入框改为可编辑状态 */
    if ( value == 'on' ){
        $('#ant_type_tab').addClass('hidden-class');
        $('#ant_type_tr').removeClass('hidden-class');
        $('#add_type_id').val('');
        SetInputValAndSetReadonlyState('#radius_id', '', 'off');
        SetInputValAndSetReadonlyState('#l1_high_id', '', 'off');
        SetInputValAndSetReadonlyState('#l2_high_id', '', 'off');
        SetInputValAndSetReadonlyState('#measure_high_id', '', 'off');
    } else {//关闭自定义，显示当前使用的天线参数
        $('#ant_type_tab').removeClass('hidden-class');
        $('#ant_type_tr').addClass('hidden-class');
        $('#ant_type_id').val(ant_param.ant_name);
        SetInputValAndSetReadonlyState('#radius_id', ant_param.radius, 'on');
        SetInputValAndSetReadonlyState('#l1_high_id', ant_param.l1_u, 'on');
        SetInputValAndSetReadonlyState('#l2_high_id', ant_param.l2_u, 'on');
        SetInputValAndSetReadonlyState('#measure_high_id', ant_param.base_high, 'on');
    }
}

/*******************************************************************************
 * 名称：PacketAntInfoToOBJ
 * 功能：打包天线参数到JSON对象中
 * 形参：ant_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/
function PacketAntInfoToOBJ(ant_obj)
{
    var ant_name = $('#add_type_id').val();
    var ngs_name = ant_name;//默认自定义名称即为天线认证名称
    var base_high = $('#measure_high_id').val();
    var radius = $('#radius_id').val();
    var l1_u = $('#l1_high_id').val();
    var l2_u = $('#l2_high_id').val();

    if ( 'on' == $('#sel_change_ant').val() ){//自定义
        if ( ('' === ant_name) ||
             ('' === base_high) ||
             ('' === radius) ||
             ('' === l1_u) ||
             ('' === l2_u) ){
            NoticeDialogShow(str_obj.val_null_str);
            return false;
        } else if ( (0 > base_high) || (0 > radius) || (0 > l1_u) || (0 > l2_u) ){
            NoticeDialogShow(str_obj.val_err);
            return false;
        }
        var val_option = "#ant_type_id option[value='" + ant_obj.ant_name + "']";
        $(val_option).remove();//删除原有的自定义天线名称
        $('#ant_type_id').append("<option value='" + ant_name + "' checked>"
            + ant_name + "</option>");//添加新增的自定义天线名称并改为选中状态
        ant_obj.ant_name = ant_name;
        ant_obj.ngs_name = ngs_name;//默认自定义名称即为天线认证名称
        ant_obj.base_high = base_high;
        ant_obj.radius = radius;
        ant_obj.l1_u = l1_u;
        ant_obj.l2_u = l2_u;
        ant_obj.l1_n = 0;//参照手簿软件界面显示，改值未使用，不提供修改，默认填0
        ant_obj.l1_e = 0;//参照手簿软件界面显示，改值未使用，不提供修改，默认填0
        ant_obj.l2_n = 0;//参照手簿软件界面显示，改值未使用，不提供修改，默认填0
        ant_obj.l2_e = 0;//参照手簿软件界面显示，改值未使用，不提供修改，默认填0
    } else {//非自定义
        var val = $('#ant_type_id').val();
        // console.log("current name is: " + val);
        if ( $('#ant_type_id').val() != ant_obj.ant_name ){
            $.each(ant_val_list, function (index, val){
                if( val.ant_name === $('#ant_type_id').val() ){
                    ant_obj.ant_name = ant_val_list[index].ant_name;
                    ant_obj.ngs_name = ant_val_list[index].ngs_name;
                    ant_obj.base_high = ant_val_list[index].base_high;
                    ant_obj.radius = ant_val_list[index].radius;
                    ant_obj.l1_n = ant_val_list[index].l1_n;
                    ant_obj.l1_e = ant_val_list[index].l1_e;
                    ant_obj.l1_u = ant_val_list[index].l1_u;
                    ant_obj.l2_n = ant_val_list[index].l2_n;
                    ant_obj.l2_e = ant_val_list[index].l2_e;
                    ant_obj.l2_u = ant_val_list[index].l2_u;
                }
            });
        }
    }
    // console.log("packet ant is: " + ant_obj);
}
/*******************************************************************************
 * 名称：SetAntlInfo
 * 功能：设置天线参数
 * 形参：
 * 返回：空
 * 说明：
 ******************************************************************************/

function SetAntlInfo(){

    var ret = PacketAntInfoToOBJ(ant_param);
    if ( ret == false ){
        return false;
    }
    var strs = '&' + JSON.stringify(ant_param);
    console.log("set JSON ant_param is: " + strs);

    showLoader(str_obj.setting_str, 0); /* 显示设置中不自动消失 */
    var timeout_interval = setTimeout(function() {
        showLoader(str_obj.set_failed_str, 1000);
    }, 5000);

    iRTK5HTTPRequest('system&set_ant', strs, function(dat)
    {
        console.log(dat); /* 向控制台输出接收到的CGI数据 */
        /* 此处显示设置状态开关 */
        showLoader(str_obj.set_success_str, 1000);
        clearTimeout(timeout_interval); /* 清除time out 间隔 */
        console.log("CGI OK!");
    });

}
