/*******************************************************************************
 * PorjectName : iRTK5WEB FileName : canvas_sat.js Module Function : Created on :
 * 2016年12月12日 Author : admin
 ******************************************************************************/


/* 以下全局变量存放屏幕相关参数 此处用于做宏定义使用 */

/*
 * 卫星 类 / 0: GPS 1: SBAS 2: GLONASS 3: Galileo 4: QZSS 5:BeiDou 一一对应关系
 */

var sat_class_arr = ['gps_id', 'sbas_id', 'gls_id', 'ges_id', 'qzss_id', 'bds_id']; /* 所属卫星类别 */
var sat_class_pre = ['G', 'S', 'R', 'E', 'J', 'C']; /* 所属卫星类别 */

var name_arr = ["GPS", "SBAS", "GLN", "GAL", "QZSS", "BDS"]; /* 卫星名称缩写 */

var id_arr = ["gps_cnt", "sbas_cnt", "gls_cnt", "ges_cnt", "qzss_cnt", "bds_cnt"]; /* 显示卫星数统计id数组 */

var checked_arr = ['gps_checked_id', 'sbas_checked_id', 'gls_checked_id', 'ges_checked_id', 'qzss_checked_id', 'bds_checked_id']; /* 显示/隐藏复选框id */

/* 以上全局变量存放屏幕相关参数 此处用于做宏定义使用 */

/* json 格式width ->x htight ->y 全局变量 */
/* 卫星信息JSON格式数组 */
var sat_info_arr = [ /* 卫星信息数组 */ 
	{
	classes: 1,
	/*
	 * 卫星 类 / 0: GPS 1: SBAS 2: GLONASS 3: Galileo 4: QZSS 5: BeiDou
	 */
	prn: 100,
	/* 卫星号 */
	elev: 0,
	/* 卫星仰角 0-90 */
	azim: 0,
	/* 方位角 0-359 */
	snr: 48,
	/* 信噪比 0-99 一般 小于L1 50 */
	L2: 40,
	/* L2信噪比 */
	L3: 41,
	/* L3信噪比 */
	used: 1 /* 1 使用中 0 未使用 */
	}, 
];


/*******************************************************************************
 * 名称：CheckSatInfo 功能：检查卫星信息的正确性 形参： info -> 单颗卫星json格式数据 返回： true or false
 * 说明：卫星所属为 0-5 azim 为 0-360 elev 0-90 L1/L2/L3 0-255/4
 ******************************************************************************/

function CheckSatInfo(info) 
{
	var tmp = {
		classes: 0,
		/* 卫星 类 / sat_bds/sat_gls/sat_ges/sat_sbas/sat_qzss */
		prn: 1,
		/* 卫星号 */
		elev: 40,
		/* 卫星仰角 0-90 */
		azim: 90,
		/* 方位角 0-359 */
		snr: 48,
		/* 信噪比 0-99 一般 小于L1 50 */
		L2: 40,
		/* L2信噪比 */
		L3: 41,
		/* L3信噪比 */
		used: 1 /* 1 使用中 0 未使用 */
	};
	tmp = info; /* 更新信息 */
	
	if (10 == tmp.classes) {
		tmp.classes = 1; /* RTX 归类为 SBAS*/
	}
	
	
	if (((tmp.classes >= 0) && (tmp.classes <= 6)) &&
		((tmp.prn > 0) && (tmp.prn < 255)) &&
		((tmp.elev >= 0) && (tmp.elev <= 90)) &&
		((tmp.azim >= 0) && (tmp.azim < 360)) &&
		((tmp.snr >= 0) && (tmp.snr <= 99)) &&
		((tmp.L2 >= 0) && (tmp.L2 <= 99)) &&
		((tmp.L3 >= 0) && (tmp.L3 <= 99))) {
		return true; /* 数据正确返回成功 */
	}
	return false;
}


/* 以下部分用于调试 */
function getRandom(n) 
{
	return Math.floor(Math.random() * n + 1);
}

function CreateDataBase(cnt) 
{
	var DataArr = []; /* JSON格式数据 */

	var tmp = {
		classes: 0,
		/* 卫星 类 / sat_bds/sat_gls/sat_ges/sat_sbas/sat_qzss */
		prn: 1,
		/* 卫星号 */
		elev: 40,
		/* 卫星仰角 0-90 */
		azim: 90,
		/* 方位角 0-359 */
		snr: 48,
		/* 信噪比 0-99 一般 小于L1 50 */
		L2: 40,
		/* L2信噪比 */
		L3: 41,
		/* L3信噪比 */
		used: 1 /* 1 使用中 0 未使用 */
	};


	for (var i = 0; i < cnt; i++) {
		tmp = {
			classes: getRandom(6) - 1,
			/*
			 * 卫星 类 / sat_bds/sat_gls/sat_ges/sat_sbas/sat_qzss
			 */
			prn: getRandom(200) + 1,
			/* 卫星号 */
			elev: getRandom(90),
			/* 卫星仰角 0-90 */
			azim: getRandom(360),
			/* 方位角 0-359 */
			snr: getRandom(50),
			/* 信噪比 0-99 一般 小于50 */
			L2: getRandom(50),
			/* L2信噪比 */
			L3: getRandom(50),
			/* L3信噪比 */
			used: getRandom(2) - 1 /* 1 使用中 0 未使用 */
		};
		DataArr.push(tmp); /* 添加一个object */

	}
	SatDataSorts(DataArr, 'prn', true); /* 默认对PRN进行排序 */
	return DataArr; /* 返回数据数组 */

}

sat_info_arr = CreateDataBase(1); /* 此处用于调试 */

/* 以上部分用于调试 */

/*******************************************************************************
 * 名称：DrawBaseList 功能：绘制卫星列表 形参：id -> 卫星列表id sat_obj -> 仰角及方位角 JSON对象 返回： 空 说明：无
 ******************************************************************************/

function DrawBaseList(id, sat_obj) 
{
	// alert(document.getElementById(id).innerHTML);
	var strs = ""; /* 字符串中间变量 */
	var use_flag = 0; /* 使用标准默认为不使用 */

	for (var i = 0; i < sat_obj.length; i++) {

		if (CheckSatInfo(sat_obj[i]) == false) {
			continue; /* 如果卫星信息不正确则不更新列表 */
		}
		
		if (10 == sat_obj[i].classes) { /* RTX 标记为 与SBAS 相同  */
			sat_obj[i].classes = 1;
		}
		
		use_flag = sat_obj[i].used & (1 << 6); /* used in current position */
//		use_flag = sat_obj[i].used & (1 << 7);
		/*
		 * used in the current RTK solution
		 */
		/* 0和非0 */
		strs += "<tr class=\'" + sat_class_arr[sat_obj[i].classes] + "\'><td width='16%'";
		strs += (use_flag) ? 'class=\"use_class\" >' : 'class=\"unuse_class\">';
		strs += sat_class_pre[sat_obj[i].classes] + sat_obj[i].prn + "</td>";
		strs += "<td width='14%'>" + sat_obj[i].elev + "</td>";
		strs += "<td width='16%'>" + sat_obj[i].azim + "</td>";
		strs += "<td width='17%'>" + sat_obj[i].snr + "</td>";
		strs += "<td width='17%'>" + sat_obj[i].L2 + "</td>";
		strs += "<td width='20%'>" + sat_obj[i].L3 + "</td>";
		strs += "</tr>";

	}
	$('#' + id).html(strs);

	$('#sat_tbody tr:odd').addClass("alt"); /* 选择奇数个 0开始编码 增加alt */
	/* 以下为更新卫星数量 */
	$('#sat_tbody tr:even').addClass('clearbg-class');

	for (i = 0; i < id_arr.length; i++) {
		/* 统计 卫星数 */
		$('#' + id_arr[i]).html(name_arr[i] + "+" + FormatNumToString(document.getElementsByClassName(sat_class_arr[i]).length, 2));


		if ($('#' + checked_arr[i]).get(0).checked) {
			$('.' + sat_class_arr[i]).removeClass('hidden-class'); /*
																	 * 删除隐藏的显示
																	 * 当复选框为checked
																	 */

		} else {
			$('.' + sat_class_arr[i]).addClass('hidden-class'); /* 增加选择和删除选择 */
		}

	}

	console.log($('.use_class').length);
	console.log($('#sat_tbody tr').length);


}


/*******************************************************************************
 * 名称：CalCordinatefromItem 功能：根据仰角及方位角计算XY坐标 形参：radius -> 圆半径 Item -> 仰角及方位角
 * JSON对象 返回： JSON格式对象 说明：无
 ******************************************************************************/

function CalCordinatefromItem(radius, Item) 
{

	var cordinate = {
		x: 0,
		y: 0,
	};

	var cosLen = (radius / 90) * (90 - Item.elev); /* 数学运算 */

	cordinate.y = Math.cos((Item.azim * Math.PI) / 180) * cosLen;
	cordinate.x = Math.sin((Item.azim * Math.PI) / 180) * cosLen;

	return cordinate; /* 返回json 格式对象 */
}



/*******************************************************************************
 * 名称：SatDataSorts 功能：卫星数据排序 形参： dat -> Json格式原始数据 sort_type -> json 成员名
 * sort_mod -> 强制排序模式 (true:强制升序 false: 根据当前排序情况排序) 返回：排序后的数据 说明：无
 ******************************************************************************/

function SatDataSorts(dat, sort_type, sort_mod) 
{
	/* 判断第0个数据和第一个数据的 类型 */
	if (!sort_mod && (dat[0][sort_type] < dat[1][sort_type])) {
		/*
		 * a < b 表示原本为降序 则改为 升序排列
		 */
		dat.sort(function (a, b) {
			return b[sort_type] - a[sort_type]
		}); /* 降序排列 */
	} else {
		dat.sort(function (a, b) {
			return a[sort_type] - b[sort_type]
		}); /* 升序排列 */
	}

	return dat;
}

/*******************************************************************************
 * 名称：SatDataSortApp 功能：卫星数据排序 形参：sort_type -> json 成员名 返回：排序后的数据 说明：无
 ******************************************************************************/

function SatDataSortApp(sort_type) 
{
	satlite_info = SatDataSorts(satlite_info, sort_type, false); /* 默认对PRN进行排序 */
	DrawBaseList('sat_tbody', satlite_info);
}


/*******************************************************************************
 * 名称：RefreshSatlitesInfoPage 功能：更新卫星信息页面 形参： page_type - > 页面类型 list map
 * sat_obj -> 卫星数据 返回：空 说明：无
 ******************************************************************************/

function RefreshSatlitesInfoPage(page_type, sat_obj) 
{

	if (page_type == 'list') { /* 卫星列表 */
		DrawBaseList('sat_tbody', sat_obj);
	} else if (page_type == 'map') { /* 星空图 */
		ReDrawCanvas(sat_obj);
	} else {


	}
}

/*******************************************************************************
 * 名称：CheckRepeatSatlitesInfo 
 * 功能：检查重复的卫星信息 
 * 形参：satlite_info -> 卫星信息对象
 * 返回：过滤后的卫星信息
 * 说明：传入的卫星信息对象需为排序后的对象
 ******************************************************************************/

function CheckRepeatSatlitesInfo(satlite_info) 
{

	var i = 0;
	
	for (i = 0; i < satlite_info.length; i++) {
		if (i < (satlite_info.length - 1)) {
			if (satlite_info[i] == satlite_info[i+1]) {
				console.log(satlite_info[i]);
				satlite_info.splice(i+1, 1);
				i--; /* 卫星数减一，则i也应该减一  */
			}
		}
	}
	
	return satlite_info;
}

/*******************************************************************************
 * 名称：GetSatlitesInfo 功能：获取卫星信息内容 形参：无 返回：空 说明：无
 ******************************************************************************/

function GetSatlitesInfo(page_type) 
{

	iRTK5HTTPRequest('sat_info&get_satinfo', '', function (dat) {

		satlite_info = JSON.parse(dat); /* 解析数据 */
		
		satlite_info = SatDataSorts(satlite_info, 'prn', true); /* 先根据PRN排序 再根据卫星系统类型排序  */
		satlite_info = SatDataSorts(satlite_info, 'classes', true);

		satlite_info = CheckRepeatSatlitesInfo(satlite_info); /* 检查重复的卫星信息  */
		
		console.log(satlite_info); /* 向控制台打印JSON */
		RefreshSatlitesInfoPage(page_type, satlite_info);
	});
}



function CalCordifromItem(radius, Item) 
{

	var cordinate = {
		left: 0,
		top: 0,
	};

	var cosLen = (radius / 90) * (90 - Item.elev); /* 数学运算 计算从圆心开始到卫星圆心点的距离 */

	cordinate.top = Math.cos((Item.azim * Math.PI) / 180) * cosLen;

	cordinate.left = Math.sin((Item.azim * Math.PI) / 180) * cosLen;

	cordinate.top = radius - cordinate.top; /* 原点转换 */
	cordinate.left = radius + cordinate.left;

	return cordinate; /* 返回json 格式对象 */
}


/* 将标签的宽高设置为相同的属性 */
function SetElementWidthHeight(elem, attr_val) 
{
	$(elem).css("width", attr_val + 'px');
	$(elem).css("height", $(elem).css("width")); /* 30 */
}

/* 设置div宽度 */
function SetDivWidth(div_id, canvas_width, deg) 
{
	var mul = (90 - deg) / 90.0; /* float */

	SetElementWidthHeight(div_id, canvas_width * mul);

	$(div_id).css("margin-top", canvas_width * (1.0 / 6.0) + 'px');
	$(div_id).css("margin-left", canvas_width * (1.0 / 6.0) + 'px');

}


function ReDrawCanvas(json_sat_obj) 
{
	var canvas_width = parseFloat($('.div-sat-map').css("width")); /* 画布宽度 */

	$('.div-sat-map').css("height", canvas_width + 'px'); /* 0 */

	$('.canvas_line').css("top", (canvas_width / 2) + 4 + 'px');

	/* canvas 中图例宽度和高度 */

	SetElementWidthHeight('.canvas_legend', canvas_width);
	SetElementWidthHeight('#canvas_map', canvas_width);


	/* 设置为正方形 */

	SetDivWidth('.div-sat-map-t30', canvas_width, 30); /* 30度为最大宽度的2/3 */
	SetDivWidth('.div-sat-map-t60', canvas_width, 60); /* 60度为最大宽度的1/3 */
	SetDivWidth('.div-sat-map-t90', canvas_width, 90); /* 90度为最大宽度的0/3 */


	/* 此处开始绘制卫星星空图数据 */
	console.log(json_sat_obj.length); /* 当前卫星信息数组 */


	var radius = canvas_width / 2.0; /* 得到圆半径 */
	/* 获取大圆半径 得到圆心坐标 为 (radius, radius) */

	$('#canvas_map').empty(); /* 清空画布 采用 append 增加 */

	var sat_id_str = "";
	var title_str = ""; /* title 属性需要增加的信息 */
	var cordi; /* 计算出的坐标偏移 */

	for (var i = 0; i < json_sat_obj.length; i++) {

		$('#canvas_map').append('<span class="sat-dot-map"><div class="sat-dot-font"></div></span>');

		if (CheckSatInfo(json_sat_obj[i]) == false) {
			continue; /* 如果卫星信息不正确则不更新列表 */
		}

		if (10 == json_sat_obj[i].classes) { /* RTX 标记为 与SBAS 相同  */
			json_sat_obj[i].classes = 1;
		}
		
		sat_id_str = '#canvas_map span:nth-child(' + (i + 1) + ')'; /* 从1 开始编号 */

		// sat_id_str = 'sat_id' + i;
		$(sat_id_str).attr("id", 'sat_id' + i);

		title_str = "elev:" + json_sat_obj[i].elev;
		title_str += " azim:" + json_sat_obj[i].azim;
		$(sat_id_str).attr("title", title_str);
		$(sat_id_str).addClass(sat_class_arr[json_sat_obj[i].classes]); /*
																		 * 增加卫星类
																		 * 颜色
																		 */

		$(sat_id_str + " div").html(json_sat_obj[i].prn); /* 卫星号 */

		cordi = CalCordifromItem(radius, json_sat_obj[i]); /* 计算距离 */
		/* 实际无论卫星是什么形状 移动的距离应该是卫星宽度或者高度的一半才能和圆心重合 */
		cordi.top = cordi.top - parseFloat($(sat_id_str).css("height")) / 2.0;
		cordi.left = cordi.left - parseFloat($(sat_id_str).css("width")) / 2.0;

		$(sat_id_str).css("top", cordi.top + 'px'); /* top - height */
		$(sat_id_str).css("left", cordi.left + 'px'); /* 计算坐标 决定星空图对应的点的偏移 */

	}


	for (i = 0; i < id_arr.length; i++) {
		/* 统计 卫星数 */
		$('#' + id_arr[i]).html(name_arr[i] + "+" + FormatNumToString(document.getElementsByClassName(sat_class_arr[i]).length - 1, 2));

		if ($('#' + checked_arr[i]).get(0).checked) {
			$('span.' + sat_class_arr[i]).removeClass('hidden-class'); /*
																		 * 删除隐藏的显示
																		 * 当复选框为checked
																		 */
		} else {
			$('span.' + sat_class_arr[i]).addClass('hidden-class'); /* 增加选择和删除选择 */
		}

	}


}
