/*******************************************************************************
 *  PorjectName		: iRTK5WEB
 *  FileName	  	: other_ctrl.js 
 *	Module Function : 
 *  Created on		: 2017年3月14日下午2:59:19
 *  Author	  		: Guangliang Liao @zhdwq
*******************************************************************************/

var ctrl_obj = {
    time_zone : 10, /* 时区index */
    voice_type : 0, /* 语音类型 */
	rinex_en:0,
	rinex_ver:3.02,
    volume : 50, /* 音量大小 */
	power_type: 2, /* 供电方式 */
	dev_series: 0, /* 系列号 */
	storage_mode: 0, /* 静态数据存储位置：0：内部存储，1：TF卡存储 */
    is_pps_width: 0,    /* 主板是否支持更改 pps width */
    pps_width: 10,  /* 默认10us */
    static_start_flag: 0,   /* 静态开始标志 */
    is_sup_xFill: 0,    /* 是否支持断点续测功能 */
    xFill_en: 0,    /* 断点续测功能开关 */
};

var pps_width_max = 10000;



/*******************************************************************************
 * 名称：GetControlInfo
 * 功能：获取控制设置状态
 * 形参：无
 * 返回：空
 * 说明：无
 ******************************************************************************/

function GetControlInfo()
{
	iRTK5HTTPRequest('system&get_sta', '', function(dat)
	{
		console.log(dat); /* 向控制台输出接收到的CGI数据 */
		/* 此处显示卫星跟踪开关 */
		ctrl_obj = JSON.parse(dat); /* 解析JSON数据 */
		RefreshControlInfoPage(ctrl_obj); /* 更新 时区等 状态 */
		console.log("CGI OK!");
	});

}

/*******************************************************************************
 * 名称：SetControlInfo
 * 功能：设置控制状态
 * 形参：无
 * 返回：空
 * 说明：无
 ******************************************************************************/

function SetControlInfo()
{
    var prame = PacketControlInfoToOBJ(ctrl_obj);
    if ( prame == false ){
        return;
    }

	var strs = '&' + JSON.stringify(prame);
	console.log(strs); /* 打印发送出去的数据 */

	showLoader(str_obj.setting_str, 0); /* 显示设置中不自动消失 */
	var timeout_interval = setTimeout(function() {
		showLoader(str_obj.set_failed_str, 1000);
	}, 5000);

	iRTK5HTTPRequest('system&set_sta', strs, function(dat)
	{
		console.log(dat); /* 向控制台输出接收到的CGI数据 */
		/* 此处显示设置状态开关 */
		showLoader(str_obj.set_success_str, 1000);
		clearTimeout(timeout_interval); /* 清除time out 间隔 */
		console.log("CGI OK!");
	});

}

/*******************************************************************************
 * 名称：RefreshControlInfoPage
 * 功能：更新控制信息状态页面
 * 形参：ctrl_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/

function RefreshControlInfoPage(ctrl_obj)
{
	$("#time_zones_id").val(ctrl_obj.time_zone);

	$('#voice_type_id').val(ctrl_obj.voice_type); /* 语音类型 */
	document.getElementById('volume_id').value = ctrl_obj.volume * 10; /* 音量大小更新 */
	ValueChange(document.getElementById('volume_id').value);

	document.getElementById('select_rinex_en').selectedIndex = ctrl_obj.rinex_en;

    //3:A8_K20系列
    if ( 3 == ctrl_obj.dev_series ){
        $("#base_detect").addClass("hidden-class");
        $("#voice_type").addClass("hidden-class");
        $("#volume").addClass("hidden-class");
		/* zrf 20220507 暂时关闭rinex功能 */
		$("#rinex_func_id").addClass("hidden-class");
		$("#rinex_version_id").addClass("hidden-class");
	} else {
        document.getElementById('base_detect_en').selectedIndex = ctrl_obj.base_detect_en; /* 基站移动检测开关  */
    }

	if ((undefined != ctrl_obj.func_option) &&
			 (0 == (ctrl_obj.func_option & 0x04000)))
	{ /* 不支持rinex 默认支持 */

		$("#rinex_func_id").addClass("hidden-class");
		document.getElementById('select_rinex_en').selectedIndex = 0; /* 关闭rinex开关  */
		$('#rinex_ver_id').val(0);
	}

	if ((undefined != ctrl_obj.rinex_ver))
	{ /* 不支持rinex 默认支持 */

		$("#rinex_ver_id").val(ctrl_obj.rinex_ver);

	}


	JqueryMobileRefresh('#select_rinex_en', "slider");
    //3:A8_K20系列
    if ( 3 != ctrl_obj.dev_series ){
        JqueryMobileRefresh('#base_detect_en', "slider");
    }

	/*
	 * document.getElementById('volume_text_id').innerHTML = '音量:' +
	 * ctrl_obj.volume;
	 */

    //3:A8_K20系列
    if ( 3 == ctrl_obj.dev_series ){
    	//供电方式
        $('#power_en').removeClass("hidder-class");
        $('#power_type_id').val(ctrl_obj.power_type);
        // 静态数据存储位置
		$('#storage_option_tab').removeClass("hidder_class");
		$('#storge_option_select_id').val(ctrl_obj.storage_mode);
	}

    if ( ctrl_obj.is_pps_width ){
		if(7 == ctrl_obj.oem_type){		//和芯板卡
			document.getElementById("pps_width_id").setAttribute("placeholder",str_obj.pps_width_placeholder_500ms);
		}
		else{
			document.getElementById("pps_width_id").setAttribute("placeholder",str_obj.pps_width_placeholder_10ms);
		}
		$('#pps_width_id').val(ctrl_obj.pps_width);
    }

    if ( ctrl_obj.is_sup_xFill ){
        $('#xFill_en_id').removeClass("hidden-class");
        document.getElementById("xFill_en_sel").selectedIndex = ctrl_obj.xFill_en;
        JqueryMobileRefresh('#xFill_en_sel', "slider");
    }
}

/*******************************************************************************
* 名称：PacketControlInfoToOBJ
* 功能：打包一个控制信息到JSON对象中
* 形参：ctrl_obj	->	JSON对象
* 返回：空
* 说明：无
******************************************************************************/
function PacketControlInfoToOBJ(ctrl_obj)
{
	var json_ctrl = ctrl_obj; /* 提供一个JSON模板 */

	json_ctrl.time_zone = $("#time_zones_id").val();
    if ( 3 != ctrl_obj.dev_series ){
        json_ctrl.voice_type = $('#voice_type_id').val(); /* 语音类型 */
        json_ctrl.volume = document.getElementById('volume_id').value / 10; /* 音量大小更新 */
        json_ctrl.base_detect_en = document.getElementById('base_detect_en').selectedIndex;
    }

	json_ctrl.rinex_en = document.getElementById('select_rinex_en').selectedIndex;
	json_ctrl.rinex_ver = $("#rinex_ver_id").val();  /* rinex 版本 */
	ctrl_obj.power_type = $('#power_type_id').val(); /* 供电方式 */

    /* 若正在采静态，则不允许更改存储位置 */
    var tmp_storage_mode = $('#storge_option_select_id').val();
    if ( (ctrl_obj.static_start_flag) &&
         (json_ctrl.storage_mode != tmp_storage_mode) ){
        NoticeDialogShow(str_obj.storage_change_str);
        return false;
    } else {
        json_ctrl.storage_mode = $('#storge_option_select_id').val();
    }

	var pps_width = $('#pps_width_id').val();
	var pps_limit_str = "";
	//和芯板卡，带宽最大可以改为500ms
	if(7 == ctrl_obj.oem_type){
		pps_width_max = 500000;
		pps_limit_str = str_obj.pps_width_limit_500ms;
	}
	else{
		pps_width_max = 10000;
		pps_limit_str = str_obj.pps_width_limit_10ms;
	}

	console.log("pps_width_max :" + pps_width_max);
    if ( pps_width > pps_width_max || pps_width < 0 ){
        NoticeDialogShow(pps_limit_str);
        return false;
    } else {
        json_ctrl.pps_width = pps_width;
    }

    if ( json_ctrl.is_sup_xFill ){
        json_ctrl.xFill_en = $('#xFill_en_sel').get(0).selectedIndex;
    }
	
	return json_ctrl;
}

function ValueChange(val)
{
	$('#lable_value').html(val);
	$(".ui-input-range").css("background-size", (100 - val) + '%');
}


