/*******************************************************************************
 *  PorjectName		: iRTK5WEB
 *  FileName	  	: sat_switch.js 
 *	Module Function : 
 *  Created on		: 2017年1月19日
 *  Author	  		: admin
 *******************************************************************************/

/* 卫星跟踪开关 */
var sat_tracking = {
	gnss_supt: 0,
	gps_en: 0,
	gls_en: 0,
	ges_en: 0,
	bds_en: 0,
	sbas_en: 0,
	qzss: 0,
	cutoff: 0,
};


/*******************************************************************************
 * 名称：GetSatliteTrackingSta
 * 功能：获取卫星跟踪状态
 * 形参：无
 * 返回：空
 * 说明：无
 ******************************************************************************/

function GetSatliteTrackingSta() 
{
	iRTK5HTTPRequest('sat_track&get_sattrack', '', function (dat) {
		console.log(dat); /* 向控制台输出接收到的CGI数据 */
		/* 此处显示卫星跟踪开关 */
		sat_tracking = JSON.parse(dat); /* 解析JSON数据 */
		RefreshSatTrackPage(sat_tracking); /* 更新 track状态 */
		console.log("CGI OK!");
	});

}

/*******************************************************************************
 * 名称：SetSatliteTrackingSta
 * 功能：设置卫星跟踪状态
 * 形参：无
 * 返回：空
 * 说明：无
 ******************************************************************************/

function SetSatliteTrackingSta() 
{
	var strs = JSON.stringify(PacketSatTrackToOBJ(sat_tracking));
	
	
	if ("false" == strs || false == strs) {
		return ;
	}
	
	console.log(strs); /* 打印发送出去的数据 */

	showLoader(str_obj.setting_str, 0); /* 显示设置中不自动消失 */
	var timeout_interval = setTimeout(function () {
		showLoader(str_obj.set_failed_str, 1000);
	}, 5000);

	iRTK5HTTPRequest('sat_track&set_sattrack', '&' +  strs, function (dat) {
		console.log(dat); /* 向控制台输出接收到的CGI数据 */
		/* 此处显示卫星跟踪开关 */
		showLoader(str_obj.set_success_str, 1000);
		clearTimeout(timeout_interval); /* 清除time out 间隔 */

		console.log("CGI OK!");
	});

}

/*******************************************************************************
 * 名称：RefreshSatTrackPage
 * 功能：更新卫星跟踪页面
 * 形参：track_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/

function RefreshSatTrackPage(track_obj) 
{
	/* 以下为每个 select 对应的id 和json命名 */
	var sele_arr = [
		'select_gps', 'select_ges', 'select_bds', 'select_sbas',
		'select_qzss', 'select_gls'
	];
	var name_arr = [
		'gps_en', 'ges_en', 'bds_en', 'sbas_en', 'qzss_en', 'gls_en'
	];

	/* 以下隐藏不支持的卫星系统的设置 */
	/* 以下两个数组一一对应关系 对应于协议中的位定义 */
	var div_arr = [
		"gps_div", "bds_div", "ges_div", "gls_div", "sbas_div", "qzss_div"
	];
	var offset_arr = [
		2, 1, 4, 0, 3, 5
	];

	for (var i = 0; i < div_arr.length; i++) {
		// document.getElementById(sele_arr[i]).checked =
		// track_obj[name_arr[i]]; /* 设置状态 */
		/* 以下由于jqm 无法局部渲染 需要重新刷新 */

		/* 不使用jqm 则不需要局部刷新  */
		/*		$('#' + sele_arr[i]).attr("checked",
				        (track_obj[name_arr[i]] > 0) ? true : false).checkboxradio(
				        "refresh");*/
		/*
		$('#' + sele_arr[i]).attr("checked",
		        (track_obj[name_arr[i]] > 0) ? true : false);*/


		document.getElementById(sele_arr[i]).selectedIndex = track_obj[name_arr[i]];
		JqueryMobileRefresh('#' + sele_arr[i], "slider");
		SetElementStyleById(div_arr[i],
			(track_obj.gnss_supt & (1 << offset_arr[i])) ?
			'' :
			'display:none');
	}

	$('#select_cutoff').val(track_obj.cutoff + "°");

}

/*******************************************************************************
 * 名称：PacketSatTrackToOBJ
 * 功能：打包一个卫星跟踪状态到JSON对象中
 * 形参：track_obj	->	JSON对象
 * 返回：空
 * 说明：无
 ******************************************************************************/
function PacketSatTrackToOBJ(track_obj) 
{
	var json_track = track_obj; /* 提供一个JSON模板 */

	json_track.gps_en = document.getElementById('select_gps').selectedIndex; /* 读取状态 */
	json_track.ges_en = document.getElementById('select_ges').selectedIndex; /* 读取状态 */
	json_track.bds_en = document.getElementById('select_bds').selectedIndex; /* 读取状态 */
	json_track.sbas_en = document.getElementById('select_sbas').selectedIndex; /* 读取状态 */
	json_track.qzss_en = document.getElementById('select_qzss').selectedIndex; /* 读取状态  */
	json_track.gls_en = document.getElementById('select_gls').selectedIndex; /* 读取状态  */
	json_track.cutoff = parseInt($('#select_cutoff').val());

	console.log("cutoff :" + json_track.cutoff);

	if (
		(typeof json_track.cutoff != 'number') ||
		(isNaN(json_track.cutoff)) ||
		(0 > json_track.cutoff) ||
		(30 < json_track.cutoff)
	) {
		NoticeDialogShow(str_obj.dead_deg_notice_str);
		return false;
	}
	
	if (0 == json_track.gps_en && 0 == json_track.bds_en) {
		
		NoticeDialogShow(str_obj.gps_bds_notice_str);
		
		return false;
	}
	
	
	return json_track;
}
